@@ -469,23 +469,28 @@ def _validate_filepath(filepath, extension="json"):
 
 def _read_json(filepath, mode, cypher=None):
     """ Read and parse JSON file to Python dictionary. """
+    temp = ""
     encrypted, content = False, {}
     filepath = _validate_filepath(filepath)
     keys = ("arkivist", "encryption", "content")
-    with open(filepath, mode, encoding="utf-8") as f:
-        temp = RE_WHITESPACES.sub("", f.read()).strip()
-        if temp[:2] in ("", "{}"):
-            return encrypted, content
-        content = json.loads(temp)
-        if len(content) == len(keys):
-            encrypted = all([(key in content) for key in keys])
-            if encrypted and isinstance(cypher, str):
-                if not (
-                    content["arkivist"] >= 1.2 and content["encryption"] == "fernet"
-                ):
-                    ArkivistException("The file is not compatible with Arkivist.")
-                content = content["content"].encode("utf-8")
-                content = json.loads(cypher.decrypt(content).decode())
+    try:
+        with open(filepath, mode, encoding="utf-8") as f:
+            temp = RE_WHITESPACES.sub("", f.read()).strip()
+    except:
+        with open(filepath, "w", encoding="utf-8") as f:
+            f.write("{}")
+    if temp[:2] in ("", "{}"):
+        return encrypted, content
+    content = json.loads(temp)
+    if len(content) == len(keys):
+        encrypted = all([(key in content) for key in keys])
+        if encrypted and isinstance(cypher, str):
+            if not (
+                content["arkivist"] >= 1.2 and content["encryption"] == "fernet"
+            ):
+            ArkivistException("The file is not compatible with Arkivist.")
+            content = content["content"].encode("utf-8")
+            content = json.loads(cypher.decrypt(content).decode())
     return encrypted, content
 
 def _write_json(obj, forced=False):
